@@ -147,10 +147,10 @@ fn display_snap(sn: SnapshotFile) {
         table.add_row([bold_cell(title), Cell::new(value)]);
     };
 
-    add_entry("Snapshot", sn.id.to_hex());
+    add_entry("Snapshot", sn.id.to_hex().to_string());
     // note that if original was not set, it is set to sn.id by the load process
     if sn.original != Some(sn.id) {
-        add_entry("Original ID", sn.original.unwrap().to_hex());
+        add_entry("Original ID", sn.original.unwrap().to_hex().to_string());
     }
     add_entry("Time", sn.time.format("%Y-%m-%d %H:%M:%S").to_string());
     add_entry("Generated by", sn.program_version);
@@ -166,11 +166,11 @@ fn display_snap(sn: SnapshotFile) {
     add_entry("Paths", sn.paths.formatln());
     let parent = match sn.parent {
         None => "no parent snapshot".to_string(),
-        Some(p) => p.to_hex(),
+        Some(p) => p.to_hex().to_string(),
     };
     add_entry("Parent", parent);
     if let Some(summary) = sn.summary {
-        add_entry("", "".to_string());
+        add_entry("", String::new());
         add_entry("Command", summary.command);
 
         let source = format!(
@@ -180,7 +180,7 @@ fn display_snap(sn: SnapshotFile) {
             bytes(summary.total_bytes_processed)
         );
         add_entry("Source", source);
-        add_entry("", "".to_string());
+        add_entry("", String::new());
 
         let files = format!(
             "new: {:>10} / changed: {:>10} / unchanged: {:>10}",
@@ -193,7 +193,7 @@ fn display_snap(sn: SnapshotFile) {
             summary.dirs_new, summary.dirs_changed, summary.dirs_unmodified,
         );
         add_entry("Dirs", trees);
-        add_entry("", "".to_string());
+        add_entry("", String::new());
 
         let written = format!(
             "data:  {:>10} blobs / raw: {:>10} / packed: {:>10}\n\
